
## Units of Measurement

For an introduction on dealing with units in Java, see
[Baeldung: Introduction to javax.measure](https://www.baeldung.com/javax-measure).

Here some examples for valid units:


| Symbol   | Dimension           
| -------- | ------------------- 
| Hz       | 1/[T] 
| Bq       | 1/[T] 
| A        | [I] 
| F        | [I]²·[T]^4/([L]²·[M]) 
| S        | [I]²·[T]³/([L]²·[M]) 
| C        | [I]·[T] 
| cd       | [J] 
| lm       | [J] 
| lx       | [J]/[L]² 
| m        | [L] 
| m/s      | [L]/[T] 
| km/h     | [L]/[T] 
| m/s²     | [L]/[T]² 
| m²       | [L]² 
| Sv       | [L]²/[T]² 
| Gy       | [L]²/[T]² 
| H        | [L]²·[M]/([I]²·[T]²) 
| Ω        | [L]²·[M]/([I]²·[T]³) 
| Wb       | [L]²·[M]/([I]·[T]²) 
| V        | [L]²·[M]/([I]·[T]³) 
| J        | [L]²·[M]/[T]² 
| W        | [L]²·[M]/[T]³ 
| l        | [L]³ 
| m³       | [L]³ 
| N        | [L]·[M]/[T]² 
| kg       | [M] 
| g        | [M] 
| T        | [M]/([I]·[T]²) 
| Pa       | [M]/([L]·[T]²) 
| mol      | [N] 
| kat      | [N]/[T] 
| h        | [T] 
| year     | [T] 
| s        | [T] 
| day      | [T] 
| week     | [T] 
| min      | [T] 
| K        | [Θ] 
| ℃        | [Θ] 
| one      | one 
| %        | one 
| rad      | one 
| sr       | one 

Some units of special interest for Urban Simulation, partly introduced with Plug-in "City Units":

| Symbol   | Dimension           
| -------- | -------------- 
| W·s      | [L]²·[M]/[T]² 
| W·h      | [L]²·[M]/[T]² 
| kW·h     | [L]²·[M]/[T]² 
| MW·h     | [L]²·[M]/[T]² 
| m³/min   | [L]³/[T] 
| m³/h     | [L]³/[T] 
| m³/s     | [L]³/[T] 
| m³/d     | [L]³/[T] 
| l/min    | [L]³/[T] 
| W/m²     | [M]/[T]³ 
| ppm      | one 
| dB       | one 
| €        | [$]
| $        | [$]

Note that monetary units have been added ad hoc to City Untis to model costs, but may be abandoned in future.
